@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2013 ZNC, see the NOTICE file for details.
+ * Copyright (C) 2004-2014 ZNC, see the NOTICE file for details.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -102,7 +102,7 @@ public:
 	 * @return An integer less than, equal to, or greater than zero if this
 	 *         string smaller, equal.... to the given string.
 	 */
-	int CaseCmp(const CString& s, unsigned long uLen = CString::npos) const;
+	int CaseCmp(const CString& s, CString::size_type uLen = CString::npos) const;
 	/**
 	 * Compare this string case sensitively to some other string.
 	 * @param s The string to compare to.
@@ -110,7 +110,7 @@ public:
 	 * @return An integer less than, equal to, or greater than zero if this
 	 *         string smaller, equal.... to the given string.
 	 */
-	int StrCmp(const CString& s, unsigned long uLen = CString::npos) const;
+	int StrCmp(const CString& s, CString::size_type uLen = CString::npos) const;
 	/**
 	 * Check if this string is equal to some other string.
 	 * @param s The string to compare to.
@@ -119,7 +119,7 @@ public:
 	 * @param uLen Number of characters to consider.
 	 * @return True if the strings are equal.
 	 */
-	bool Equals(const CString& s, bool bCaseSensitive = false, unsigned long uLen = CString::npos) const;
+	bool Equals(const CString& s, bool bCaseSensitive = false, CString::size_type uLen = CString::npos) const;
 	/**
 	 * Do a wildcard comparision between two strings.
 	 * For example, the following returns true:
