@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2013 ZNC, see the NOTICE file for details.
+ * Copyright (C) 2004-2014 ZNC, see the NOTICE file for details.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -362,10 +362,6 @@ CString CZNC::GetUserPath() const {
 CString CZNC::GetModPath() const {
 	CString sModPath = m_sZNCPath + "/modules";
 
-	if (!CFile::Exists(sModPath)) {
-		CDir::MakeDir(sModPath);
-	}
-
 	return sModPath;
 }
 
@@ -578,29 +574,26 @@ bool CZNC::WriteNewConfig(const CString& sConfigFile) {
 
 	do {
 		bSuccess = true;
-		while (!CUtils::GetNumInput("What port would you like ZNC to listen on?", uListenPort, 1025, 65535)) ;
+		while (true) {
+			if (!CUtils::GetNumInput("What port would you like ZNC to listen on?", uListenPort, 1025, 65535)) {
+				continue;
+			}
+			if (uListenPort == 6667 && !CUtils::GetBoolInput("Warning: Some web browsers reject port 6667. If you intend to use ZNC's web interface, you might want to use another port. Proceed with port 6667 anyway?", true)) {
+				continue;
+			}
+			break;
+		}
+
 
 #ifdef HAVE_LIBSSL
-		if (CUtils::GetBoolInput("Would you like ZNC to listen using SSL?", bListenSSL)) {
-			bListenSSL = true;
-
-			CString sPemFile = GetPemLocation();
-			if (!CFile::Exists(sPemFile)) {
-				CUtils::PrintError("Unable to locate pem file: [" + sPemFile + "]");
-				if (CUtils::GetBoolInput("Would you like to create a new pem file now?",
-							true)) {
-					WritePemFile();
-				}
-			}
-		} else
-			bListenSSL = false;
+		bListenSSL = CUtils::GetBoolInput("Would you like ZNC to listen using SSL?", bListenSSL);
 #endif
 
 #ifdef HAVE_IPV6
-		b6 = CUtils::GetBoolInput("Would you like ZNC to listen using ipv6?", b6);
+		b6 = CUtils::GetBoolInput("Would you like ZNC to listen using both IPv4 and IPv6?", b6);
 #endif
 
-		CUtils::GetInput("Listen Host", sListenHost, sListenHost, "Blank for all ips");
+		// Don't ask for listen host, it may be configured later if needed.
 
 		CUtils::PrintAction("Verifying the listener");
 		CListener* pListener = new CListener((unsigned short int)uListenPort, sListenHost, bListenSSL,
@@ -613,6 +606,14 @@ bool CZNC::WriteNewConfig(const CString& sConfigFile) {
 		delete pListener;
 	} while (!bSuccess);
 
+#ifdef HAVE_LIBSSL
+	CString sPemFile = GetPemLocation();
+	if (!CFile::Exists(sPemFile)) {
+		CUtils::PrintMessage("Unable to locate pem file: [" + sPemFile + "], creating it");
+		WritePemFile();
+	}
+#endif
+
 	vsLines.push_back("<Listener l>");
 	vsLines.push_back("\tPort = " + CString(uListenPort));
 	vsLines.push_back("\tIPv4 = true");
